#!/usr/bin/env python3
from distutils.core import setup
import subprocess
import os
import sys
import importlib.resources

with importlib.resources.path('srht', 'Makefile') as f:
    srht_path = f.parent.as_posix()

make = os.environ.get("MAKE", "make")
subp = subprocess.run([make, "SRHT_PATH=" + srht_path])
if subp.returncode != 0:
    sys.exit(subp.returncode)

ver = os.environ.get("PKGVER") or subprocess.run(['git', 'describe', '--tags'],
      stdout=subprocess.PIPE).stdout.decode().strip()

setup(
  name = 'dispatchsrht',
  packages = [
      'dispatchsrht',
      'dispatchsrht.alembic',
      'dispatchsrht.alembic.versions',
      'dispatchsrht.blueprints',
      'dispatchsrht.tasks',
      'dispatchsrht.tasks.github',
      'dispatchsrht.tasks.gitlab',
      'dispatchsrht.types',
  ],
  version = ver,
  description = 'dispatch.sr.ht website',
  author = 'Drew DeVault',
  author_email = 'sir@cmpwn.com',
  url = 'https://dispatch.sr.ht/~sircmpwn/dispatch.sr.ht',
  license = 'AGPL-3.0',
  package_data={
      'dispatchsrht': [
          'templates/*.html',
          'templates/github/*.html',
          'templates/gitlab/*.html',
          'static/*',
          'static/icons/*',
      ]
  },
  scripts = [
      'dispatchsrht-initdb',
      'dispatchsrht-migrate',
  ],
)
